.. :changelog:

History
-------

1.0.1 (2016-10-19)
++++++++++++++++++

* Added support for Python 3.4 and current Django stable
* Fix a thread bug that would make the package usable only for test and not for real :/

1.0.0 (2016-09-15)
++++++++++++++++++

* First stable version

0.2.0 (2016-09-14)
++++++++++++++++++

* Rationalized the writing of readonly (vs read-only)
* Defined default app config

0.1.1 (2016-09-13)
++++++++++++++++++

* CI improvements
* Code linting


0.1.0 (2016-09-02)
++++++++++++++++++

* First release on PyPI.
